// <copyright file="BrowsingContextStorageModule.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using System.Threading.Tasks;
using OpenQA.Selenium.BiDi.Modules.Storage;

namespace OpenQA.Selenium.BiDi.Modules.BrowsingContext;

public class BrowsingContextStorageModule(BrowsingContext context, StorageModule storageModule)
{
    public Task<GetCookiesResult> GetCookiesAsync(GetCookiesOptions? options = null)
    {
        options ??= new();

        options.Partition = new ContextPartitionDescriptor(context);

        return storageModule.GetCookiesAsync(options);
    }

    public async Task<PartitionKey> DeleteCookiesAsync(DeleteCookiesOptions? options = null)
    {
        options ??= new();

        options.Partition = new ContextPartitionDescriptor(context);

        var res = await storageModule.DeleteCookiesAsync(options).ConfigureAwait(false);

        return res.PartitionKey;
    }

    public async Task<PartitionKey> SetCookieAsync(PartialCookie cookie, SetCookieOptions? options = null)
    {
        options ??= new();

        options.Partition = new ContextPartitionDescriptor(context);

        var res = await storageModule.SetCookieAsync(cookie, options).ConfigureAwait(false);

        return res.PartitionKey;
    }
}
